Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AllowedConfigPaths ¶
AllowedConfigPaths returns all allowed config paths derived from currently registered CLI commands. It includes both section paths (objects) and leaf paths (flags), e.g.:
gitlab gitlab.scan gitlab.scan.search
func GenerateExampleConfig ¶
GenerateExampleConfig builds a YAML template from the currently registered CLI commands and flags.
func IsAllowedConfigPath ¶
IsAllowedConfigPath returns true when the given dotted key path is part of the generated config schema.
func IsAllowedReadConfigPath ¶
IsAllowedReadConfigPath returns true when the path is readable from config schema. Read operations allow both: - Exact leaf keys (e.g., gitlab.token) - Section prefixes that contain allowed leaf keys (e.g., gitlab, gitlab.scan)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.